@@ -21,11 +21,17 @@
  */
 #include <gmodule.h>
 #include <gtk/gtk.h>
+#include "ge-support.h"
  
+/*****************************/
+/* Pattern Fills             */
+/*****************************/
+#define DEFAULT_BACKGROUND_PATTERN(redmond_style, state) ((redmond_style->bg_image[state])?redmond_style->bg_image[state]:redmond_style->bg_color[state])
+
 /*****************************/
 /* RC Style Declaration      */
 /*****************************/
-extern GType redmond_type_rc_style;
+GE_INTERNAL extern GType redmond_type_rc_style;
  
 #define REDMOND_TYPE_RC_STYLE              redmond_type_rc_style
 #define REDMOND_RC_STYLE(object)           (G_TYPE_CHECK_INSTANCE_CAST ((object), REDMOND_TYPE_RC_STYLE, RedmondRcStyle))
@@ -37,8 +43,6 @@ extern GType redmond_type_rc_style;
 typedef struct
 {
   GtkRcStyle parent_instance;
- 
-  GList *img_list;
 } RedmondRcStyle;
  
 typedef struct
@@ -49,7 +53,7 @@ typedef struct
 /*****************************/
 /* Drawing Style Declaration */
 /*****************************/
-extern GType redmond_type_style;
+GE_INTERNAL extern GType redmond_type_style;
  
 #define REDMOND_TYPE_STYLE              redmond_type_style
 #define REDMOND_STYLE(object)           (G_TYPE_CHECK_INSTANCE_CAST ((object), REDMOND_TYPE_STYLE, RedmondStyle))
@@ -61,8 +65,13 @@ extern GType redmond_type_style;
 typedef struct
 {
   GtkStyle parent_instance;
-  GdkGC *black_border_gc[5];
-  GdkColor black_border[5];
+
+  CairoColor black_border[5];
+  CairoColorCube color_cube;
+
+  CairoPattern *bg_color[5];
+  CairoPattern *bg_image[5];
+  CairoPattern hatch_mask;
 } RedmondStyle;
  
 typedef struct
